-- =============================================
-- SaveToDB Framework for PostgreSQL
-- Version 7.19, March 12, 2018
--
-- This script upgrades SaveToDB Framework 5.x to SaveToDB Framework 7.19
--
-- Copyright 2015-2018 Gartle Technology Corporation
-- =============================================

CREATE OR REPLACE VIEW savetodb_dev.view_query_list
AS
SELECT
    t.table_schema
    , t.table_name
    , t.table_type
    , NULL AS table_code
    , COALESCE(q.insert_procedure, CASE WHEN i.routine_name IS NULL THEN NULL ELSE i.routine_schema || '.' || i.routine_name END) AS insert_procedure
    , COALESCE(q.update_procedure, CASE WHEN u.routine_name IS NULL THEN NULL ELSE u.routine_schema || '.' || u.routine_name END) AS update_procedure
    , COALESCE(q.delete_procedure, CASE WHEN d.routine_name IS NULL THEN NULL ELSE d.routine_schema || '.' || d.routine_name END) AS delete_procedure
    , COALESCE(q.procedure_type, CASE WHEN i.routine_name IS NOT NULL THEN 'FUNCTION' ELSE NULL END) AS procedure_type
FROM
    information_schema.tables t
    LEFT OUTER JOIN information_schema.routines i ON i.routine_schema = t.table_schema AND i.routine_name = replace(t.table_name, '_select', '') || '_insert'
    LEFT OUTER JOIN information_schema.routines u ON u.routine_schema = t.table_schema AND u.routine_name = replace(t.table_name, '_select', '') || '_update'
    LEFT OUTER JOIN information_schema.routines d ON d.routine_schema = t.table_schema AND d.routine_name = replace(t.table_name, '_select', '') || '_delete'
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.table_schema = t.table_schema AND q.table_name = t.table_name
WHERE
    NOT t.table_schema IN ('information_schema', 'pg_catalog')
UNION
SELECT
    r.routine_schema AS table_schema
    , r.routine_name AS table_name
    , r.routine_type AS table_type
    , NULL AS table_code
    , COALESCE(q.insert_procedure, CASE WHEN i.routine_name IS NULL THEN NULL ELSE i.routine_schema || '.' || i.routine_name END) AS insert_procedure
    , COALESCE(q.update_procedure, CASE WHEN u.routine_name IS NULL THEN NULL ELSE u.routine_schema || '.' || u.routine_name END) AS update_procedure
    , COALESCE(q.delete_procedure, CASE WHEN d.routine_name IS NULL THEN NULL ELSE d.routine_schema || '.' || d.routine_name END) AS delete_procedure
    , COALESCE(q.procedure_type, CASE WHEN i.routine_name IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS procedure_type
FROM 
    information_schema.routines r
    LEFT OUTER JOIN information_schema.routines i ON i.routine_schema = r.routine_schema AND i.routine_name = replace(r.routine_name, '_select', '') || '_insert'
    LEFT OUTER JOIN information_schema.routines u ON u.routine_schema = r.routine_schema AND u.routine_name = replace(r.routine_name, '_select', '') || '_update'
    LEFT OUTER JOIN information_schema.routines d ON d.routine_schema = r.routine_schema AND d.routine_name = replace(r.routine_name, '_select', '') || '_delete'
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.table_schema = r.routine_schema AND q.table_name = r.routine_name
WHERE
    NOT r.routine_schema IN ('information_schema', 'pg_catalog')
    AND r.routine_type = 'FUNCTION'
    AND NOT (
        r.routine_name LIKE '%_insert'
        OR r.routine_name LIKE '%_update'
        OR r.routine_name LIKE '%_delete'
        OR r.routine_name LIKE '%_merge'
        OR r.routine_name LIKE '%_change'
    )
UNION
SELECT
    q.table_schema
    , q.table_name
    , q.table_type
    , q.table_code
    , q.insert_procedure
    , q.update_procedure
    , q.delete_procedure
    , q.procedure_type
FROM
    savetodb_dev.query_list q
    LEFT OUTER JOIN information_schema.tables t ON q.table_schema = t.table_schema AND q.table_name = t.table_name
    LEFT OUTER JOIN information_schema.routines r ON q.table_schema = r.routine_schema AND q.table_name = r.routine_name
WHERE
    q.table_type IN ('CODE', 'HTTP', 'TEXT')
    AND t.table_name IS NULL
    AND r.routine_name IS NULL
ORDER BY
    table_schema
    , table_name;

GRANT SELECT ON TABLE savetodb_dev.view_query_list TO savetodb_dev_role;

DELETE FROM savetodb_dev.table_formats WHERE "table_schema" = 'savetodb_dev' AND "table_name" = 'event_handlers';

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','event_handlers','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.event_handlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="ColumnWidth" value="11.71" type="Double" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="15" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="22.86" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="column_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="column_name" property="Address" value="$F$4" type="String" />
<column name="column_name" property="ColumnWidth" value="15.71" type="Double" />
<column name="column_name" property="NumberFormat" value="General" type="String" />
<column name="column_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="column_name" property="Validation.Type" value="6" type="Double" />
<column name="column_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="column_name" property="Validation.Operator" value="8" type="Double" />
<column name="column_name" property="Validation.Formula1" value="64" type="String" />
<column name="column_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="column_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="event_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="event_name" property="Address" value="$G$4" type="String" />
<column name="event_name" property="ColumnWidth" value="15" type="Double" />
<column name="event_name" property="NumberFormat" value="General" type="String" />
<column name="event_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="event_name" property="Validation.Type" value="3" type="Double" />
<column name="event_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="event_name" property="Validation.Operator" value="8" type="Double" />
<column name="event_name" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="event_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="event_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="event_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="event_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_schema" property="Address" value="$H$4" type="String" />
<column name="handler_schema" property="ColumnWidth" value="17.14" type="Double" />
<column name="handler_schema" property="NumberFormat" value="General" type="String" />
<column name="handler_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_name" property="Address" value="$I$4" type="String" />
<column name="handler_name" property="ColumnWidth" value="35.71" type="Double" />
<column name="handler_name" property="NumberFormat" value="General" type="String" />
<column name="handler_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_name" property="Validation.Type" value="6" type="Double" />
<column name="handler_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="handler_name" property="Validation.Operator" value="8" type="Double" />
<column name="handler_name" property="Validation.Formula1" value="2000" type="String" />
<column name="handler_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="handler_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="handler_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="handler_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_type" property="Address" value="$J$4" type="String" />
<column name="handler_type" property="ColumnWidth" value="14.29" type="Double" />
<column name="handler_type" property="NumberFormat" value="General" type="String" />
<column name="handler_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_type" property="Validation.Type" value="3" type="Double" />
<column name="handler_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="handler_type" property="Validation.Operator" value="1" type="Double" />
<column name="handler_type" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String" />
<column name="handler_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="handler_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="handler_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="handler_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_code" property="Address" value="$K$4" type="String" />
<column name="handler_code" property="ColumnWidth" value="42.14" type="Double" />
<column name="handler_code" property="NumberFormat" value="General" type="String" />
<column name="handler_code" property="VerticalAlignment" value="-4160" type="Double" />
<column name="target_worksheet" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="target_worksheet" property="Address" value="$L$4" type="String" />
<column name="target_worksheet" property="ColumnWidth" value="22.86" type="Double" />
<column name="target_worksheet" property="NumberFormat" value="General" type="String" />
<column name="target_worksheet" property="VerticalAlignment" value="-4160" type="Double" />
<column name="target_worksheet" property="Validation.Type" value="6" type="Double" />
<column name="target_worksheet" property="Validation.AlertStyle" value="1" type="Double" />
<column name="target_worksheet" property="Validation.Operator" value="8" type="Double" />
<column name="target_worksheet" property="Validation.Formula1" value="64" type="String" />
<column name="target_worksheet" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.ShowError" value="True" type="Boolean" />
<column name="menu_order" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="menu_order" property="Address" value="$M$4" type="String" />
<column name="menu_order" property="ColumnWidth" value="13.57" type="Double" />
<column name="menu_order" property="NumberFormat" value="General" type="String" />
<column name="menu_order" property="VerticalAlignment" value="-4160" type="Double" />
<column name="menu_order" property="Validation.Type" value="1" type="Double" />
<column name="menu_order" property="Validation.AlertStyle" value="1" type="Double" />
<column name="menu_order" property="Validation.Operator" value="1" type="Double" />
<column name="menu_order" property="Validation.Formula1" value="-32768" type="String" />
<column name="menu_order" property="Validation.Formula2" value="32767" type="String" />
<column name="menu_order" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="menu_order" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="menu_order" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="menu_order" property="Validation.ShowError" value="True" type="Boolean" />
<column name="edit_parameters" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="edit_parameters" property="Address" value="$N$4" type="String" />
<column name="edit_parameters" property="ColumnWidth" value="17.43" type="Double" />
<column name="edit_parameters" property="NumberFormat" value="General" type="String" />
<column name="edit_parameters" property="VerticalAlignment" value="-4160" type="Double" />
<column name="edit_parameters" property="Validation.Type" value="1" type="Double" />
<column name="edit_parameters" property="Validation.AlertStyle" value="1" type="Double" />
<column name="edit_parameters" property="Validation.Operator" value="1" type="Double" />
<column name="edit_parameters" property="Validation.Formula1" value="-32768" type="String" />
<column name="edit_parameters" property="Validation.Formula2" value="32767" type="String" />
<column name="edit_parameters" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.ShowError" value="True" type="Boolean" />
<column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="is_active" property="Address" value="$O$4" type="String" />
<column name="is_active" property="ColumnWidth" value="10.29" type="Double" />
<column name="is_active" property="NumberFormat" value="General" type="String" />
<column name="is_active" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="event_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="SortFields(4)" property="KeyfieldName" value="menu_order" type="String" />
<column name="SortFields(4)" property="SortOn" value="0" type="Double" />
<column name="SortFields(4)" property="Order" value="1" type="Double" />
<column name="SortFields(4)" property="DataOption" value="0" type="Double" />
<column name="SortFields(5)" property="KeyfieldName" value="handler_name" type="String" />
<column name="SortFields(5)" property="SortOn" value="0" type="Double" />
<column name="SortFields(5)" property="Order" value="1" type="Double" />
<column name="SortFields(5)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');

-- 7.19

DELETE FROM savetodb_dev.table_formats WHERE "table_schema" = 'savetodb_dev' AND "table_name" = 'parameter_values';

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','parameter_values','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.parameter_values">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="14.57" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="16.43" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="parameter_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="parameter_name" property="Address" value="$F$4" type="String" />
<column name="parameter_name" property="ColumnWidth" value="17.86" type="Double" />
<column name="parameter_name" property="NumberFormat" value="General" type="String" />
<column name="parameter_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="parameter_name" property="Validation.Type" value="6" type="Double" />
<column name="parameter_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="parameter_name" property="Validation.Operator" value="8" type="Double" />
<column name="parameter_name" property="Validation.Formula1" value="64" type="String" />
<column name="parameter_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="parameter_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="parameter_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="parameter_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_schema" property="Address" value="$G$4" type="String" />
<column name="select_schema" property="ColumnWidth" value="15.71" type="Double" />
<column name="select_schema" property="NumberFormat" value="General" type="String" />
<column name="select_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="select_schema" property="Validation.Type" value="6" type="Double" />
<column name="select_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="select_schema" property="Validation.Operator" value="8" type="Double" />
<column name="select_schema" property="Validation.Formula1" value="64" type="String" />
<column name="select_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="select_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="select_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="select_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_name" property="Address" value="$H$4" type="String" />
<column name="select_name" property="ColumnWidth" value="30" type="Double" />
<column name="select_name" property="NumberFormat" value="General" type="String" />
<column name="select_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="select_name" property="Validation.Type" value="6" type="Double" />
<column name="select_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="select_name" property="Validation.Operator" value="8" type="Double" />
<column name="select_name" property="Validation.Formula1" value="64" type="String" />
<column name="select_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="select_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="select_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="select_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_type" property="Address" value="$I$4" type="String" />
<column name="select_type" property="ColumnWidth" value="12.86" type="Double" />
<column name="select_type" property="NumberFormat" value="General" type="String" />
<column name="select_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="select_type" property="Validation.Type" value="3" type="Double" />
<column name="select_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="select_type" property="Validation.Operator" value="8" type="Double" />
<column name="select_type" property="Validation.Formula1" value="TABLE;VIEW;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String" />
<column name="select_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="select_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="select_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="select_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_code" property="Address" value="$J$4" type="String" />
<column name="select_code" property="ColumnWidth" value="58.86" type="Double" />
<column name="select_code" property="NumberFormat" value="General" type="String" />
<column name="select_code" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="parameter_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');

ALTER TABLE savetodb_dev.event_handlers ALTER COLUMN handler_name DROP NOT NULL;

INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);

DELETE FROM savetodb_dev.table_formats WHERE "table_schema" = 'savetodb_dev' AND "table_name" = 'event_handlers';

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','event_handlers','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.event_handlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="ColumnWidth" value="11.71" type="Double" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="15" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="22.86" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="column_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="column_name" property="Address" value="$F$4" type="String" />
<column name="column_name" property="ColumnWidth" value="15.71" type="Double" />
<column name="column_name" property="NumberFormat" value="General" type="String" />
<column name="column_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="column_name" property="Validation.Type" value="6" type="Double" />
<column name="column_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="column_name" property="Validation.Operator" value="8" type="Double" />
<column name="column_name" property="Validation.Formula1" value="64" type="String" />
<column name="column_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="column_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="event_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="event_name" property="Address" value="$G$4" type="String" />
<column name="event_name" property="ColumnWidth" value="15" type="Double" />
<column name="event_name" property="NumberFormat" value="General" type="String" />
<column name="event_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="event_name" property="Validation.Type" value="3" type="Double" />
<column name="event_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="event_name" property="Validation.Operator" value="8" type="Double" />
<column name="event_name" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="event_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="event_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="event_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="event_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_schema" property="Address" value="$H$4" type="String" />
<column name="handler_schema" property="ColumnWidth" value="17.14" type="Double" />
<column name="handler_schema" property="NumberFormat" value="General" type="String" />
<column name="handler_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_name" property="Address" value="$I$4" type="String" />
<column name="handler_name" property="ColumnWidth" value="35.71" type="Double" />
<column name="handler_name" property="NumberFormat" value="General" type="String" />
<column name="handler_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_name" property="Validation.Type" value="6" type="Double" />
<column name="handler_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="handler_name" property="Validation.Operator" value="8" type="Double" />
<column name="handler_name" property="Validation.Formula1" value="2000" type="String" />
<column name="handler_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="handler_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="handler_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="handler_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_type" property="Address" value="$J$4" type="String" />
<column name="handler_type" property="ColumnWidth" value="14.29" type="Double" />
<column name="handler_type" property="NumberFormat" value="General" type="String" />
<column name="handler_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_type" property="Validation.Type" value="3" type="Double" />
<column name="handler_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="handler_type" property="Validation.Operator" value="1" type="Double" />
<column name="handler_type" property="Validation.Formula1" value="TABLE;VIEW;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="handler_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="handler_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="handler_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="handler_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_code" property="Address" value="$K$4" type="String" />
<column name="handler_code" property="ColumnWidth" value="42.14" type="Double" />
<column name="handler_code" property="NumberFormat" value="General" type="String" />
<column name="handler_code" property="VerticalAlignment" value="-4160" type="Double" />
<column name="target_worksheet" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="target_worksheet" property="Address" value="$L$4" type="String" />
<column name="target_worksheet" property="ColumnWidth" value="22.86" type="Double" />
<column name="target_worksheet" property="NumberFormat" value="General" type="String" />
<column name="target_worksheet" property="VerticalAlignment" value="-4160" type="Double" />
<column name="target_worksheet" property="Validation.Type" value="6" type="Double" />
<column name="target_worksheet" property="Validation.AlertStyle" value="1" type="Double" />
<column name="target_worksheet" property="Validation.Operator" value="8" type="Double" />
<column name="target_worksheet" property="Validation.Formula1" value="64" type="String" />
<column name="target_worksheet" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.ShowError" value="True" type="Boolean" />
<column name="menu_order" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="menu_order" property="Address" value="$M$4" type="String" />
<column name="menu_order" property="ColumnWidth" value="13.57" type="Double" />
<column name="menu_order" property="NumberFormat" value="General" type="String" />
<column name="menu_order" property="VerticalAlignment" value="-4160" type="Double" />
<column name="menu_order" property="Validation.Type" value="1" type="Double" />
<column name="menu_order" property="Validation.AlertStyle" value="1" type="Double" />
<column name="menu_order" property="Validation.Operator" value="1" type="Double" />
<column name="menu_order" property="Validation.Formula1" value="-32768" type="String" />
<column name="menu_order" property="Validation.Formula2" value="32767" type="String" />
<column name="menu_order" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="menu_order" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="menu_order" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="menu_order" property="Validation.ShowError" value="True" type="Boolean" />
<column name="edit_parameters" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="edit_parameters" property="Address" value="$N$4" type="String" />
<column name="edit_parameters" property="ColumnWidth" value="17.43" type="Double" />
<column name="edit_parameters" property="NumberFormat" value="General" type="String" />
<column name="edit_parameters" property="VerticalAlignment" value="-4160" type="Double" />
<column name="edit_parameters" property="Validation.Type" value="1" type="Double" />
<column name="edit_parameters" property="Validation.AlertStyle" value="1" type="Double" />
<column name="edit_parameters" property="Validation.Operator" value="1" type="Double" />
<column name="edit_parameters" property="Validation.Formula1" value="-32768" type="String" />
<column name="edit_parameters" property="Validation.Formula2" value="32767" type="String" />
<column name="edit_parameters" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.ShowError" value="True" type="Boolean" />
<column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="is_active" property="Address" value="$O$4" type="String" />
<column name="is_active" property="ColumnWidth" value="10.29" type="Double" />
<column name="is_active" property="NumberFormat" value="General" type="String" />
<column name="is_active" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="event_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="SortFields(4)" property="KeyfieldName" value="menu_order" type="String" />
<column name="SortFields(4)" property="SortOn" value="0" type="Double" />
<column name="SortFields(4)" property="Order" value="1" type="Double" />
<column name="SortFields(4)" property="DataOption" value="0" type="Double" />
<column name="SortFields(5)" property="KeyfieldName" value="handler_name" type="String" />
<column name="SortFields(5)" property="SortOn" value="0" type="Double" />
<column name="SortFields(5)" property="Order" value="1" type="Double" />
<column name="SortFields(5)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');
